import { transformRequest } from './transform';

let files = [];

const isFile = item =>
  global.window && (item instanceof File || item instanceof Blob)
    && item.size;

const formatItem = item => {
  const value = item !== null
    ? item
    : '';

  let type = typeof item;

  if (typeof item === 'object') {
    type = Array.isArray(item)
      ? 'array'
      : 'object';
  }

  if (isFile(item)) {
    type = 'file';
  }

  switch (type) {
    case 'file':
      files.push(value);
      return '__________file___________';

    case 'array':
      return value.map(formatItem);

    case 'object': {
      const struct = {};
      Object.keys(value).forEach(key => {
        const v = value[key];

        // Avoid passing invalid values to struct so that either
        // the JSON.parse will fail (on Firefox) or server call will fail.
        if (v === null
          || typeof v === 'undefined'
          || (typeof v === 'number' && isNaN(v))
          || v === Infinity
          || v === -Infinity) {
          return;
        }

        struct[key] = formatItem(v);
      });

      return struct;
    }

    default:
      return value;
  }
};

export default (originalArgs, options = {}) => {
  // reset files
  files = [];

  const formattedArgs = [...originalArgs]
    .map(item => formatItem(item, options));

  return {
    formattedArgs: transformRequest(formattedArgs, options),
    files,
  };
};
