const MOCKS = [];

export const clearMocks = () => MOCKS.length = 0;

export const mock = (input, response) => {
  // Array of requests to return the same response
  // e.g mock(['360.this', '360.that'], { test: false })
  if (Array.isArray(input)) {
    input.forEach(item => mock(item, response));
    return;
  }

  // Map
  if (typeof input === 'object') {
    Object.keys(input)
      .forEach(item => mock(item, input[item]));
  }

  if (typeof input === 'function'
    || typeof input === 'string'
    || input instanceof RegExp
  ) {
    MOCKS.push([input, response]);
  }
};

const parseResponse = (response, { m, a }) => {
  if (typeof response !== 'function') {
    return response;
  }

  // if we are dealing with a method, then pass arguments first and then method
  return response(a, m);
};

export const getMockedResponse = ({ m, a }) => {
  if (!MOCKS.length) {
    return undefined;
  }

  for (const [test, response] of MOCKS) {
    // String
    if (typeof test === 'string' && test === m) {
      return parseResponse(response, ({ m, a }));
    }

    // Regexp
    if (test instanceof RegExp && test.test(m)) {
      return parseResponse(response, ({ m, a }));
    }

    // Function
    if (typeof test === 'function') {
      const result = test(m, a);

      if (result) {
        return parseResponse(response, ({ m, a }));
      }
    }
  }

  return undefined;
};
