import download from 'downloadjs';

const endpoint = 'https://hal.bestprice.gr/pdf';

export default async props => {
  if (typeof props === 'string') {
    props = {
      content: props,
    };
  }

  const { content, css } = props;

  if (!content) {
    throw new Error('Content missing.');
  }

  let { name = 'pdf' } = props;

  if (name && name.indexOf('.pdf') === -1) {
    name = [name, 'pdf'].join('.');
  }

  const formData = new FormData();

  formData.append('content', content);

  if (css) {
    formData.append('css', css);
  }

  if (name) {
    formData.append('name', name);
  }

  try {
    const res = await fetch(endpoint, {
      method: 'post',
      body: formData,
    });

    const blob = await res.blob();

    download(blob, name, 'application/json');
  } catch (error) {
    return error;
  }
};
