import fetch from 'isomorphic-unfetch';

const endpoint = 'https://hal.bestprice.gr/svg';

/**
 * This method will take a file, pass it to endppoint and get back the contens to the client.
 * @param  {File} file              The input file.
 * @param  {Object} options         The extra plugins to append to the default ones.
 * @return {String|Object}          The normalized SVG string.
 */
export default async (file, options = {}) => {
  if (!file) {
    throw new Error('File not passed.');
  }

  const {
    plugins,
    verbose,
    precision,
  } = options;

  const formData = new FormData();
  formData.append('file', file);

  if (plugins) {
    formData.append('plugins', JSON.stringify(plugins));
  }

  if (verbose) {
    formData.append('verbose', 1);
  }

  if (precision) {
    formData.append('precision', precision);
  }

  try {
    const res = await fetch(endpoint, {
      method: 'post',
      body: formData,
    });

    return await res.json();
  } catch (error) {
    return error;
  }
};
