const toSnakeCase = key => key.replace(/([A-Z])/g, match => `_${match.toLowerCase()}`);

const toCamelCase = (key = '') => key.replace(/([-_][a-z])/gi, match => match.toUpperCase().replace('-', '').replace('_', ''));

const getIterator = method => {
  const walker = o => {
    if (!o) {
      return o;
    }

    if (typeof o === 'number' || typeof o === 'string' || typeof o === 'boolean') {
      return o;
    }

    if (Array.isArray(o)) {
      return o.map(i => walker(i));
    } else if (typeof o === 'object') {
      const n = {};
      Object.keys(o).forEach(k => (n[method(k)] = walker(o[k])));
      return n;
    }

    return o;
  };

  return walker;
};

export const transformResponse = (response, options = {}) => {
  if (!options.transform && !options.transformResponse) {
    return response;
  }

  const getDefaultValue = func => (func === true ? getIterator(toCamelCase) : func);

  const transformer = getDefaultValue(options.transformResponse) || getDefaultValue(options.transform);

  return transformer(response);
};

export const transformRequest = (request, options = {}) => {
  if (!options.transform && !options.transformRequest) {
    return request;
  }

  const getDefaultValue = func => (func === true ? getIterator(toSnakeCase) : func);

  const transformer = getDefaultValue(options.transformRequest) || getDefaultValue(options.transform);

  const re = transformer(request);

  console.log(re, request);
  return re;
};

