
/*
 * We used to export a folder (using babel), but this is not optimal.
 * This is the correct way to do it - by serving a umd lib.
 *
 * Please not that for node you need to import from 'fetchrpc/node' now
 */
const webpack = require('webpack');
const BundleAnalyzerPlugin = require('webpack-bundle-analyzer')
  .BundleAnalyzerPlugin;

const web = {
  mode: 'production',
  entry: {
    index: './src/index.js',
    svg: './src/svg.js',
    pdf: './src/pdf.js',
  },
  output: {
    path: `${__dirname}/lib`,
    filename: '[name].js',
    libraryTarget: 'umd',
  },

  externals: [
    'iconv-lite',
    'ip',
  ],

  module: {
    rules: [
      {
        test: /\.js$/,
        use: 'babel-loader',
        exclude: /node_modules/,
      },
    ],
  },

  plugins: [new webpack.IgnorePlugin(/(buffer|^ip$|toISO)/)],

  externals: {
    react: 'react',
  }
};

const configLibrary = {
  mode: 'production',
  target: 'web',
  output: {
    path: `${__dirname}/lib`,
    filename: 'fetch-rpc.js',
    // Will default to var
    library: 'fetchRPC',
    libraryExport: 'default',
  },
  module: {
    rules: [
      {
        test: /\.js$/,
        use: 'babel-loader',
        exclude: /node_modules/,
      },
    ],
  },

  plugins: [new webpack.IgnorePlugin(/(buffer|^ip$|toISO)/)],
};

module.exports = [
  configLibrary,
  web,
  {
    ...web,
    ...web,
    entry: './src/index.js',
    output: {
      ...web.output,
      filename: 'es.js',
    },
    module: {
      rules: [
        {
          test: /\.js$/,
          use: {
            loader: 'babel-loader',
            options: {
              envName: 'es',
            },
          },
          exclude: /node_modules/,
        },
      ],
    },

    plugins: process.env.ANALYZE
      ? [new BundleAnalyzerPlugin()]
      : [],
  },
  {
    ...web,
    entry: './src/index.js',
    target: 'node',
    output: {
      ...web.output,
      filename: 'node.js',
      libraryTarget: 'umd',
      libraryExport: 'default',
    },
    module: {
      // Needed to solve rwquire issue
      noParse: [/isomorphic-unfetch/],
      ...web.module,
    },
    resolve: {
      alias: {
        // A little trick to avoid issues related to ip module not being discoverable
        // when testing.
        './getLocalEndpoint$': require('path').resolve(__dirname, 'src', 'getLocalEndPointNode.js'),
      },
    },
    plugins: [],
    externals: [],
  },
];
